@@ -127,10 +127,10 @@ makedist()
 	echo Copying driver
 	cp -R driver $DIST/
 
-	echo Copying crossplatform data
-	if [ -d "$DL/crossplatform" ] ; then
-		cp -R $DL/crossplatform $DISTLIB/
-	fi
+	echo Copying python binding
+	mkdir -p $DISTLIB/crossplatform/wrappers/python
+	cp -R wrappers/python/src/libximc $DISTLIB/crossplatform/wrappers/python/
+	cp wrappers/python/where-did-pyximc.py-go.txt $DISTLIB/crossplatform/wrappers/python/
 
 	echo Copying c-profiles
 	if [ -d "$DL/../c-profiles" ] ; then
@@ -146,40 +146,18 @@ makedist()
 	for arch in deb rpm macosx win32 win64 ; do
 		mkdir -p $DISTLIB/$arch
 	done
-
 	cp -R $DL/deb/*.deb $DISTLIB/deb/
 	ls $DL/deb/
-	for arch in amd64 i386 armhf ; do		
-		
-		namearch=$(find $DL/deb -name "libximc7_*_$arch.deb")
-		namearch_dev=$(find $DL/deb -name "libximc7-dev_*_$arch.deb")
-		echo $namearch
-		if [ -f "$namearch" ]
+	for arch in amd64 i386 armhf ; do
+		lib_dir=$(find $DL -name "debian-$arch")
+		echo $arch
+		if [ -n "$lib_dir" ]
 		then
-			mkdir -p $DL/deb/$arch
-			mkdir -p $DL/deb/dev-$arch
 			mkdir -p $DISTLIB/debian-$arch
-
-			ar -x $namearch data.tar.gz 
-			mv -f data.tar.gz $DL/deb/$arch
-			tar -C $DL/deb/$arch/ -zxf  $DL/deb/$arch/data.tar.gz
-			
-			ar -x $namearch_dev data.tar.gz
-			mv -f data.tar.gz $DL/deb/dev-$arch
-			tar -C $DL/deb/dev-$arch/ -zxf  $DL/deb/dev-$arch/data.tar.gz
-		
-			cp -R $DL/deb/$arch/usr/lib/*.* $DISTLIB/debian-$arch/
-			cp -R $DL/deb/dev-$arch/usr/lib/*.* $DISTLIB/debian-$arch/
-			
-			rm -rf $DL/deb/$arch
-			rm -rf $DL/deb/dev-$arch
-			
+			cp -R $lib_dir/ $DISTLIB/debian-$arch/
 		else
-			echo No archive file
+			echo No corresponding files
 		fi
-		
-
-		
 	done
 
 	cp -R $DL/rpm/*.rpm $DISTLIB/rpm/
@@ -318,6 +296,7 @@ makedist()
 
 	tar -C dist -czf dist/ximc-$VER.tar.gz ximc-$VER
 	tar -C dist -czf dist/ximc-$VER-src.tar.gz ximc-$VER-src
+	cd wrappers/python/dist/ ; tar -cf ../../../dist/python-binding-$VER.tar * ; cd -
 
 	unset COPYFILE_DISABLE
 }
@@ -521,8 +500,6 @@ build_osx_impl()
 	(cd examples/test_Java && $MAKE) || false
 	cp -a examples/test_Java/test_Java.jar $DL/$DISTNAME/
 	cp -a examples/test_Java/README.txt $DL/$DISTNAME/java-README.txt
-	mkdir -p $DL/crossplatform/wrappers/python
-	cp wrappers/python/pyximc.py $DL/crossplatform/wrappers/python
 }
 
 echo XIMC build script
