@@ -3,7 +3,7 @@
 WORKING_DIR=$(pwd) # current/working directory
 sudo apt update
 pip3 install --upgrade pip
-LIBRARY_PATH=$WORKING_DIR/../../../ximc
+LIBRARY_PATH=$WORKING_DIR/../../../ximc/crossplatform/wrappers/python/libximc/library-files/
 LINUX_ARCH=$(uname -m)
 echo Current architecture: $LINUX_ARCH
 case $LINUX_ARCH in
