@@ -172,6 +172,7 @@ typedef struct
 	BCDFlashParamsStr BCDFlashParams;
 	BCDStageParamsStr BCDStageParams;
 	BCDInfoStr BCDInfo;
+	getm_cmd_str measurements;
 	/* in microseconds */
 	uint64_t last_tick;
 	uint32_t serial;
@@ -215,10 +216,9 @@ static gets_cmd_str CalculateNewPosition(smov_cmd_str smov,
 		new_pos -= diff;
 	} else if ((gets_value.MvCmdSts & MVCMD_NAME_BITS) == MVCMD_MOVE ||
 			   (gets_value.MvCmdSts & MVCMD_NAME_BITS) == MVCMD_MOVR) {
-		if (new_pos != tgt_pos)
-			new_pos -= ximc_dmin(fabs(diff), fabs(new_pos-tgt_pos)) *
-					   sgn(new_pos-tgt_pos);
-		else {
+		new_pos += ximc_dmin(diff, fabs(new_pos - tgt_pos)) * sgn(tgt_pos - new_pos);
+		if (new_pos == tgt_pos)
+		{
 			gets_value.MvCmdSts &= ~MVCMD_RUNNING;
 			gets_value.CurSpeed = 0;
 			gets_value.uCurSpeed = 0;
@@ -227,8 +227,6 @@ static gets_cmd_str CalculateNewPosition(smov_cmd_str smov,
 	
 	gets_value.CurPosition = (uint32_t)(long long)new_pos;		
 	gets_value.uCurPosition = (int16_t)((new_pos - (long long)new_pos)*micromult);
-	
-	//last_tick = this_tick;
 
 	return gets_value;
 }
@@ -296,6 +294,7 @@ static uint16_t GetWriteDataSize(uint32_t Command)
 	return 0;
 }
 
+
 /*
 	This function gets a command-packet structure and puts response into Array.
 	The Array size must be enough to hold any single response.
@@ -318,6 +317,15 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 	memcpy(out_buf, in_buf, COMMAND_LENGTH);
 	StartPos += COMMAND_LENGTH;
 
+	/* Update position */
+	all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
+												  all->BCDFlashParams.SENG,
+												  all->BCDRamParams.GETS,
+												  all->BCDRamParams.MOVE,
+												  all->last_tick);
+	get_wallclock_us(&all->last_tick);  // TODO: think about adding this function to CalculateNewPosition(...)
+
+
 	/* data_size does not include command or crc length */
 	if (data_size != 0) /* If there is data */
 	{
@@ -330,11 +338,6 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 			case ASIA_CMD: break;
 			case MOVE_CMD:
 			{
-				all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-					all->BCDFlashParams.SENG,
-					all->BCDRamParams.GETS,
-					all->BCDRamParams.MOVE,
-					all->last_tick);
 			   move_cmd_str MoveArr;
 			   READ_STRUCTURE(MoveArr);
 			   all->BCDRamParams.MOVE.Position = MoveArr.Position;
@@ -342,18 +345,11 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 			   all->BCDRamParams.GETS.MvCmdSts = MVCMD_MOVE | MVCMD_RUNNING;
 			   all->BCDRamParams.GETS.CurSpeed = all->BCDFlashParams.SMOV.Speed;
 			   all->BCDRamParams.GETS.uCurSpeed = all->BCDFlashParams.SMOV.uSpeed;
-
-			   get_wallclock_us(&all->last_tick);
 			   break;
 			}
 
 			case MOVR_CMD:
 			{
-				all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-					all->BCDFlashParams.SENG,
-					all->BCDRamParams.GETS,
-					all->BCDRamParams.MOVE,
-					all->last_tick);
 			   movr_cmd_str MovrArr;
 			   READ_STRUCTURE(MovrArr);
 			   all->BCDRamParams.MOVE.Position += MovrArr.DeltaPosition;
@@ -361,8 +357,6 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 			   all->BCDRamParams.GETS.MvCmdSts = MVCMD_MOVR | MVCMD_RUNNING;
 			   all->BCDRamParams.GETS.CurSpeed = all->BCDFlashParams.SMOV.Speed;
 			   all->BCDRamParams.GETS.uCurSpeed = all->BCDFlashParams.SMOV.uSpeed;
-
-			   get_wallclock_us(&all->last_tick);
 			   break;
 			}
 			case SPOS_CMD:
@@ -425,71 +419,42 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 	switch (command32)
 	{
 		case STOP_CMD:
-		   all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-				all->BCDFlashParams.SENG,
-				all->BCDRamParams.GETS,
-				all->BCDRamParams.MOVE,
-				all->last_tick);
 		   all->BCDRamParams.GETS.MvCmdSts = MVCMD_STOP;
 		   all->BCDRamParams.GETS.CurSpeed = 0;
 		   all->BCDRamParams.GETS.uCurSpeed = 0;
-
-		   get_wallclock_us(&all->last_tick);
 		   break;
 		case SSTP_CMD:
-		  all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-				all->BCDFlashParams.SENG,
-				all->BCDRamParams.GETS,
-				all->BCDRamParams.MOVE,
-				all->last_tick);
 		   all->BCDRamParams.GETS.MvCmdSts = MVCMD_SSTP;
 		   all->BCDRamParams.GETS.CurSpeed = 0;
 		   all->BCDRamParams.GETS.uCurSpeed = 0;
-
-		   get_wallclock_us(&all->last_tick);
 		   break;
 		case ZERO_CMD:
-		  all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-				all->BCDFlashParams.SENG,
-				all->BCDRamParams.GETS,
-				all->BCDRamParams.MOVE,
-				all->last_tick);
 		   all->BCDRamParams.GETS.CurPosition = 0;
 		   all->BCDRamParams.GETS.uCurPosition = 0;
 		   all->BCDRamParams.GETS.EncPosition = 0;
 		   all->BCDRamParams.MOVE.Position = 0;
 		   all->BCDRamParams.MOVE.uPosition = 0;
-
-		   get_wallclock_us(&all->last_tick);
 		   break;
 		case HOME_CMD:
 		   all->BCDRamParams.GETS.MvCmdSts = MVCMD_HOME;
 		   break;
 		case LEFT_CMD:
-			all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-				all->BCDFlashParams.SENG,
-				all->BCDRamParams.GETS,
-				all->BCDRamParams.MOVE,
-				all->last_tick);
 		   all->BCDRamParams.GETS.MvCmdSts = MVCMD_LEFT | MVCMD_RUNNING;
 		   all->BCDRamParams.GETS.CurSpeed = all->BCDFlashParams.SMOV.Speed;
 		   all->BCDRamParams.GETS.uCurSpeed = all->BCDFlashParams.SMOV.uSpeed;
 		   all->BCDRamParams.GETS.CurSpeed = -all->BCDRamParams.GETS.CurSpeed;
 		   all->BCDRamParams.GETS.uCurSpeed = -all->BCDRamParams.GETS.uCurSpeed;
-
-		   get_wallclock_us(&all->last_tick);
 		   break;
+		case STMS_CMD:
+			all->measurements.Length = 25;
+			break;
+		case GETM_CMD:
+			WRITE_STRUCTURE(all->measurements);
+			break;
 		case RIGT_CMD:
-			all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-				all->BCDFlashParams.SENG,
-				all->BCDRamParams.GETS,
-				all->BCDRamParams.MOVE,
-				all->last_tick);
 		   all->BCDRamParams.GETS.MvCmdSts = MVCMD_RIGHT | MVCMD_RUNNING;
 		   all->BCDRamParams.GETS.CurSpeed = all->BCDFlashParams.SMOV.Speed;
 		   all->BCDRamParams.GETS.uCurSpeed = all->BCDFlashParams.SMOV.uSpeed;
-
-		   get_wallclock_us(&all->last_tick);
 		   break;
 		case GETS_CMD:
 		{
@@ -499,14 +464,6 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 		   all->BCDRamParams.GETS.Uusb = rand_range(480, 520);
 		   all->BCDRamParams.GETS.Iusb = rand_range(180, 210);
 		   all->BCDRamParams.GETS.CurT = 366;
-           
-		   all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-										   all->BCDFlashParams.SENG,
-										   all->BCDRamParams.GETS,
-										   all->BCDRamParams.MOVE,
-										   all->last_tick);
-		   get_wallclock_us(&all->last_tick);
-
 		   WRITE_STRUCTURE(all->BCDRamParams.GETS);
 		   break;
 	   	}
@@ -537,7 +494,6 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 		   WRITE_STRUCTURE(all->BCDInfo.DEVICE_INFO);
 		   break;
 	   	}
-
 		case REST_CMD: break;
 		case UPDF_CMD: break;
 		case CLFR_CMD: break;
@@ -549,15 +505,8 @@ static uint16_t GetData(const uint8_t *in_buf, size_t data_size, uint8_t *out_bu
 		case EERD_CMD: break;
 		case GPOS_CMD: 
 		{
-			all->BCDRamParams.GETS = CalculateNewPosition(all->BCDFlashParams.SMOV,
-										   all->BCDFlashParams.SENG,
-										   all->BCDRamParams.GETS,
-										   all->BCDRamParams.MOVE,
-										   all->last_tick);
-			
 			all->BCDRamParams.GPOS.Position    = all->BCDRamParams.GETS.CurPosition;
 			all->BCDRamParams.GPOS.uPosition   = all->BCDRamParams.GETS.uCurPosition;
-			get_wallclock_us(&all->last_tick);
 			WRITE_STRUCTURE(all->BCDRamParams.GPOS);
 			break;
 		}
