@@ -1,4 +1,4 @@
-def set_profile_8MT60_200(lib, id):
+def set_profile_8MT18_13(lib, id):
     worst_result = Result.Ok
     result = Result.Ok
 
@@ -32,7 +32,7 @@ def set_profile_8MT60_200(lib, id):
     home_settings.SlowHome = 500
     home_settings.uSlowHome = 0
     home_settings.HomeDelta = 500
-    home_settings.uHomeDelta = 200
+    home_settings.uHomeDelta = 0
     class HomeFlags_:
         HOME_USE_FAST = 256
         HOME_STOP_SECOND_BITS = 192
@@ -56,11 +56,11 @@ def set_profile_8MT60_200(lib, id):
 
     move_settings = move_settings_t()
 
-    move_settings.Speed = 1000
+    move_settings.Speed = 457
     move_settings.uSpeed = 0
-    move_settings.Accel = 1000
-    move_settings.Decel = 2000
-    move_settings.AntiplaySpeed = 50
+    move_settings.Accel = 2000
+    move_settings.Decel = 4000
+    move_settings.AntiplaySpeed = 457
     move_settings.uAntiplaySpeed = 0
     class MoveFlags_:
         RPM_DIV_1000 = 1
@@ -73,9 +73,9 @@ def set_profile_8MT60_200(lib, id):
 
     engine_settings = engine_settings_t()
 
-    engine_settings.NomVoltage = 1200
-    engine_settings.NomCurrent = 1200
-    engine_settings.NomSpeed = 4000
+    engine_settings.NomVoltage = 300
+    engine_settings.NomCurrent = 180
+    engine_settings.NomSpeed = 914
     engine_settings.uNomSpeed = 0
     class EngineFlags_:
         ENGINE_LIMIT_RPM = 128
@@ -86,8 +86,8 @@ def set_profile_8MT60_200(lib, id):
         ENGINE_MAX_SPEED = 4
         ENGINE_CURRENT_AS_RMS = 2
         ENGINE_REVERSE = 1
-    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_REVERSE
-    engine_settings.Antiplay = 50
+    engine_settings.EngineFlags = EngineFlags_.ENGINE_LIMIT_RPM | EngineFlags_.ENGINE_ACCEL_ON | EngineFlags_.ENGINE_CURRENT_AS_RMS | EngineFlags_.ENGINE_REVERSE
+    engine_settings.Antiplay = 169
     class MicrostepMode_:
         MICROSTEP_MODE_FRAC_256 = 9
         MICROSTEP_MODE_FRAC_128 = 8
@@ -99,7 +99,7 @@ def set_profile_8MT60_200(lib, id):
         MICROSTEP_MODE_FRAC_2 = 2
         MICROSTEP_MODE_FULL = 1
     engine_settings.MicrostepMode = MicrostepMode_.MICROSTEP_MODE_FRAC_256
-    engine_settings.StepsPerRev = 200
+    engine_settings.StepsPerRev = 20
     result = lib.set_engine_settings(id, byref(engine_settings))
 
     if result != Result.Ok:
@@ -137,7 +137,7 @@ def set_profile_8MT60_200(lib, id):
         POWER_SMOOTH_CURRENT = 4
         POWER_OFF_ENABLED = 2
         POWER_REDUCT_ENABLED = 1
-    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_OFF_ENABLED | PowerFlags_.POWER_REDUCT_ENABLED
+    power_settings.PowerFlags = PowerFlags_.POWER_SMOOTH_CURRENT | PowerFlags_.POWER_REDUCT_ENABLED
     result = lib.set_power_settings(id, byref(power_settings))
 
     if result != Result.Ok:
@@ -148,7 +148,7 @@ def set_profile_8MT60_200(lib, id):
 
     secure_settings.LowUpwrOff = 800
     secure_settings.CriticalIpwr = 4000
-    secure_settings.CriticalUpwr = 5000
+    secure_settings.CriticalUpwr = 5500
     secure_settings.CriticalT = 800
     secure_settings.CriticalIusb = 450
     secure_settings.CriticalUusb = 520
@@ -182,9 +182,9 @@ def set_profile_8MT60_200(lib, id):
         ENDER_SW1_ACTIVE_LOW = 2
         ENDER_SWAP = 1
     edges_settings.EnderFlags = EnderFlags_.ENDER_SW2_ACTIVE_LOW | EnderFlags_.ENDER_SW1_ACTIVE_LOW | EnderFlags_.ENDER_SWAP
-    edges_settings.LeftBorder = 1500
+    edges_settings.LeftBorder = -203
     edges_settings.uLeftBorder = 0
-    edges_settings.RightBorder = 77500
+    edges_settings.RightBorder = 11089
     edges_settings.uRightBorder = 0
     result = lib.set_edges_settings(id, byref(edges_settings))
 
@@ -290,8 +290,8 @@ def set_profile_8MT60_200(lib, id):
 
     control_settings = control_settings_t()
 
-    control_settings.MaxSpeed[0] = 100
-    control_settings.MaxSpeed[1] = 1000
+    control_settings.MaxSpeed[0] = 45
+    control_settings.MaxSpeed[1] = 457
     control_settings.MaxSpeed[2] = 0
     control_settings.MaxSpeed[3] = 0
     control_settings.MaxSpeed[4] = 0
@@ -445,8 +445,8 @@ def set_profile_8MT60_200(lib, id):
 
     stage_information = stage_information_t()
 
-    stage_information.Manufacturer = bytes([83, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    stage_information.PartNumber = bytes([56, 77, 84, 54, 48, 45, 50, 48, 48, 0, 66, 83, 49, 0, 69, 110, 49, 0, 0, 0, 0, 69, 65, 83])
+    stage_information.Manufacturer = bytes([0, 116, 97, 110, 100, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+    stage_information.PartNumber = bytes([56, 77, 84, 49, 56, 45, 49, 51, 0, 48, 88, 89, 90, 0, 89, 90, 0, 0, 0, 0, 0, 69, 65, 83])
     result = lib.set_stage_information(id, byref(stage_information))
 
     if result != Result.Ok:
@@ -455,15 +455,15 @@ def set_profile_8MT60_200(lib, id):
 
     stage_settings = stage_settings_t()
 
-    stage_settings.LeadScrewPitch = 0.5
-    stage_settings.Units = bytes([109, 109, 0, 114, 101, 101, 0, 0])
-    stage_settings.MaxSpeed = 10
-    stage_settings.TravelRange = 200
-    stage_settings.SupplyVoltageMin = 12
-    stage_settings.SupplyVoltageMax = 36
+    stage_settings.LeadScrewPitch = 0.3499999940395355
+    stage_settings.Units = bytes([0, 109, 0, 114, 101, 101, 0, 0])
+    stage_settings.MaxSpeed = 1
+    stage_settings.TravelRange = 13
+    stage_settings.SupplyVoltageMin = 0
+    stage_settings.SupplyVoltageMax = 0
     stage_settings.MaxCurrentConsumption = 0
-    stage_settings.HorizontalLoadCapacity = 8
-    stage_settings.VerticalLoadCapacity = 3
+    stage_settings.HorizontalLoadCapacity = 0.5
+    stage_settings.VerticalLoadCapacity = 0.25
     result = lib.set_stage_settings(id, byref(stage_settings))
 
     if result != Result.Ok:
@@ -472,7 +472,7 @@ def set_profile_8MT60_200(lib, id):
 
     motor_information = motor_information_t()
 
-    motor_information.Manufacturer = bytes([77, 111, 116, 105, 111, 110, 32, 67, 111, 110, 116, 114, 111, 108, 32, 80])
+    motor_information.Manufacturer = bytes([0, 111, 116, 105, 111, 110, 32, 67, 111, 110, 116, 114, 111, 108, 32, 80])
     motor_information.PartNumber = bytes([0, 67, 45, 105, 45, 52, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
     result = lib.set_motor_information(id, byref(motor_information))
 
@@ -505,7 +505,7 @@ def set_profile_8MT60_200(lib, id):
     motor_settings.SpeedConstant = 0
     motor_settings.SpeedTorqueGradient = 0
     motor_settings.MechanicalTimeConstant = 0
-    motor_settings.MaxSpeed = 5000
+    motor_settings.MaxSpeed = 2000
     motor_settings.MaxCurrent = 0
     motor_settings.MaxCurrentTime = 0
     motor_settings.NoLoadCurrent = 0
@@ -572,7 +572,7 @@ def set_profile_8MT60_200(lib, id):
     gear_information = gear_information_t()
 
     gear_information.Manufacturer = bytes([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
-    gear_information.PartNumber = bytes([0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
+    gear_information.PartNumber = bytes([49, 48, 47, 49, 32, 49, 54, 58, 49, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0])
     result = lib.set_gear_information(id, byref(gear_information))
 
     if result != Result.Ok:
@@ -581,8 +581,8 @@ def set_profile_8MT60_200(lib, id):
 
     gear_settings = gear_settings_t()
 
-    gear_settings.ReductionIn = 0
-    gear_settings.ReductionOut = 0
+    gear_settings.ReductionIn = 16
+    gear_settings.ReductionOut = 1
     gear_settings.RatedInputTorque = 0
     gear_settings.RatedInputSpeed = 0
     gear_settings.MaxOutputBacklash = 0
@@ -614,7 +614,7 @@ def set_profile_8MT60_200(lib, id):
         TS_TYPE_SEMICONDUCTOR = 2
         TS_TYPE_THERMOCOUPLE = 1
         TS_TYPE_UNKNOWN = 0
-    accessories_settings.TSSettings = TSSettings_.TS_TYPE_UNKNOWN
+    accessories_settings.TSSettings = TSSettings_.TS_TYPE_THERMOCOUPLE | TSSettings_.TS_TYPE_UNKNOWN
     class LimitSwitchesSettings_:
         LS_SHORTED = 16
         LS_SW2_ACTIVE_LOW = 8
